==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/nastaveni/uchazeci.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Roman.Szablatura
 * Date: 28.01.2016
 * Time: 12:21
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;
use RonPortal\RonPortalSettings;

if (!RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_PERSONALISTIKU)) {
    return null;
}

return [
    'caption' => 'nastaveni_uchazeci',
    'category' => 'nastaveni_sekce_personalistika',
    'name'  => 'uchazeci',
    'index' => 310,
    'storage' => 'nastaveniPersonalistiky',
    'strings' => 'person.ini',
    'items' =>
        [
            // typ rozdeleni pro filtrovani uchazecu
            [
                'name'  => 'uchazecityprozdeleniprofiltr', 'type'  => Preference::SQL_COMBOBOX,    'title' => 'Uchazeci_typrozdeleni_filtr',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni WHERE VyberoveRizeni = 1 ORDER BY Kod',
                'defaultValue' => ''
            ],

            [
                'name'  => 'uchazecityprozdeleniprofiltr2', 'type'  => Preference::SQL_COMBOBOX,    'title' => 'Uchazeci_typrozdeleni_filtr2',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni WHERE VyberoveRizeni = 1 ORDER BY Kod',
                'defaultValue' => ''
            ],

            [
                'type' => Preference::CATEGORY, 'title' => 'Uzivatelska_pole',
            ],

            [
                'name' => 'uchazeciuzivatelska1', 'type' => Preference::TEXT, 'title' => '1.', 'defaultValue' => '',
                'infoText' => 'zobraz_pole_s_nadpisy'
            ],
//            [   ---- SE: ODSTRANENO 02/2019 - nema to tu smysl, vhodnejsi je to resit standardne pomoci uzivatelskeho CSS
//                'name'  => 'sirkauzivatelskehopole1',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'infoText' => 'sirka_uzivatelskeho_pole_info', 'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska2', 'type' => Preference::TEXT, 'title' => '2.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole2',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska3', 'type' => Preference::TEXT, 'title' => '3.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole3',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska4', 'type' => Preference::TEXT, 'title' => '4.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole4',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska5', 'type' => Preference::TEXT, 'title' => '5.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole5',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska6', 'type' => Preference::TEXT, 'title' => '6.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole6',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska7', 'type' => Preference::TEXT, 'title' => '7.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole7',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska8', 'type' => Preference::TEXT, 'title' => '8.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole8',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska9', 'type' => Preference::TEXT, 'title' => '9.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole9',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska10', 'type' => Preference::TEXT, 'title' => '10.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole10',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska11', 'type' => Preference::TEXT, 'title' => '11.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole11',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//               'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska12', 'type' => Preference::TEXT, 'title' => '12.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole12',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska13', 'type' => Preference::TEXT, 'title' => '13.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole13',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska14', 'type' => Preference::TEXT, 'title' => '14.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole14',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska15', 'type' => Preference::TEXT, 'title' => '15.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole15',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska16', 'type' => Preference::TEXT, 'title' => '16.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole16',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska17', 'type' => Preference::TEXT, 'title' => '17.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole17',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska18', 'type' => Preference::TEXT, 'title' => '18.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole18',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska19', 'type' => Preference::TEXT, 'title' => '19.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole19',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska20', 'type' => Preference::TEXT, 'title' => '20.', 'defaultValue' => '',

            ],
//            [
//                'name'  => 'sirkauzivatelskehopole20',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

        ]
];

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/nastaveni/uchazeci.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Roman.Szablatura
 * Date: 28.01.2016
 * Time: 12:21
 */

namespace RonPortal\Settings;

use Ron\Controls\Preference;
use RonPortal\RonPortalSettings;

if (!RonPortalSettings::getIntValue(RonPortalSettings::POVOLIT_PERSONALISTIKU)) {
    return null;
}

return [
    'caption' => 'nastaveni_uchazeci',
    'category' => 'nastaveni_sekce_personalistika',
    'name'  => 'uchazeci',
    'index' => 310,
    'storage' => 'nastaveniPersonalistiky',
    'strings' => 'person.ini',
    'items' =>
        [
            // typ rozdeleni pro filtrovani uchazecu
            [
                'name'  => 'uchazecityprozdeleniprofiltr', 'type'  => Preference::SQL_COMBOBOX,    'title' => 'Uchazeci_typrozdeleni_filtr',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni WHERE VyberoveRizeni = 1 ORDER BY Kod',
                'defaultValue' => ''
            ],

            [
                'name'  => 'uchazecityprozdeleniprofiltr2', 'type'  => Preference::SQL_COMBOBOX,    'title' => 'Uchazeci_typrozdeleni_filtr2',
                'sql'   => 'SELECT Kod, Popis FROM TypRozdeleni WHERE VyberoveRizeni = 1 ORDER BY Kod',
                'defaultValue' => ''
            ],

            [
                'type' => Preference::CATEGORY, 'title' => 'Uzivatelska_pole',
            ],

            [
                'name' => 'uchazeciuzivatelska1', 'type' => Preference::TEXT, 'title' => '1.', 'defaultValue' => '',
                'infoText' => 'zobraz_pole_s_nadpisy'
            ],
//            [   ---- SE: ODSTRANENO 02/2019 - nema to tu smysl, vhodnejsi je to resit standardne pomoci uzivatelskeho CSS
//                'name'  => 'sirkauzivatelskehopole1',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'infoText' => 'sirka_uzivatelskeho_pole_info', 'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska2', 'type' => Preference::TEXT, 'title' => '2.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole2',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska3', 'type' => Preference::TEXT, 'title' => '3.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole3',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska4', 'type' => Preference::TEXT, 'title' => '4.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole4',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska5', 'type' => Preference::TEXT, 'title' => '5.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole5',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska6', 'type' => Preference::TEXT, 'title' => '6.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole6',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska7', 'type' => Preference::TEXT, 'title' => '7.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole7',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska8', 'type' => Preference::TEXT, 'title' => '8.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole8',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska9', 'type' => Preference::TEXT, 'title' => '9.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole9',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska10', 'type' => Preference::TEXT, 'title' => '10.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole10',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska11', 'type' => Preference::TEXT, 'title' => '11.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole11',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//               'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska12', 'type' => Preference::TEXT, 'title' => '12.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole12',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska13', 'type' => Preference::TEXT, 'title' => '13.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole13',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska14', 'type' => Preference::TEXT, 'title' => '14.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole14',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska15', 'type' => Preference::TEXT, 'title' => '15.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole15',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska16', 'type' => Preference::TEXT, 'title' => '16.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole16',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska17', 'type' => Preference::TEXT, 'title' => '17.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole17',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska18', 'type' => Preference::TEXT, 'title' => '18.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole18',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska19', 'type' => Preference::TEXT, 'title' => '19.', 'defaultValue' => '',
            ],
//            [
//                'name'  => 'sirkauzivatelskehopole19',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

            [
                'name' => 'uchazeciuzivatelska20', 'type' => Preference::TEXT, 'title' => '20.', 'defaultValue' => '',

            ],
//            [
//                'name'  => 'sirkauzivatelskehopole20',    'type'  => Preference::TEXT,        'title' => 'sirka_uzivatelskeho_pole',
//                'defaultValue' => '60'
//            ],

        ]
];
